# Managing Fact Sheet Tags Dynamically Based on Relation Changes
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/managing-fact-sheet-tags-dynamically-based-on-relation-changes#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/managing-fact-sheet-tags-dynamically-based-on-relation-changes#prerequisites)
  * [Step 1: Create Tag Groups](https://help.sap.com/docs/leanix/ea/managing-fact-sheet-tags-dynamically-based-on-relation-changes#step-1:-create-tag-groups)
  * [Step 2: Create a Webhook for Fact Sheet Relations](https://help.sap.com/docs/leanix/ea/managing-fact-sheet-tags-dynamically-based-on-relation-changes#step-2:-create-a-webhook-for-fact-sheet-relations)
  * [Step 3: Create and Deploy a Function](https://help.sap.com/docs/leanix/ea/managing-fact-sheet-tags-dynamically-based-on-relation-changes#step-3:-create-and-deploy-a-function)
  * [Summary](https://help.sap.com/docs/leanix/ea/managing-fact-sheet-tags-dynamically-based-on-relation-changes#summary)


Learn how to set up an event-triggered automation that assigns or removes fact sheet tags on creating or removing relations to a specific fact sheet type.
